@@ -280,6 +280,7 @@ class ImagePlotContainer(object):
         name = old_object._type_name
         kwargs = dict((n, getattr(old_object, n))
                       for n in old_object._con_args)
+        kwargs['center'] = getattr(old_object, 'center', None)
         if data_source is not None:
             if name != "proj":
                 raise RuntimeError("The data_source keyword argument "
@@ -289,6 +290,12 @@ class ImagePlotContainer(object):
         self.ds = new_ds
         self.data_source = new_object
         self._data_valid = self._plot_valid = False
+        for d in 'xyz':
+            lim_name = d+'lim'
+            if hasattr(self, lim_name):
+                lim = getattr(self, lim_name)
+                lim = tuple(new_ds.quan(l.value, str(l.units)) for l in lim)
+                setattr(self, lim_name, lim)
         self._recreate_frb()
         self._setup_plots()
 
@@ -456,7 +463,7 @@ class ImagePlotContainer(object):
         if type in ['Projection', 'OffAxisProjection']:
             weight = self.data_source.weight_field
             if weight is not None:
-                weight = weight.replace(' ', '_')
+                weight = weight[1].replace(' ', '_')
         if 'Cutting' in self.data_source.__class__.__name__:
             type = 'OffAxisSlice'
         for k, v in self.plots.iteritems():
@@ -468,8 +475,6 @@ class ImagePlotContainer(object):
                 # for cutting planes
                 n = "%s_%s_%s" % (name, type, k.replace(' ', '_'))
             if weight:
-                if isinstance(weight, tuple):
-                    weight = weight[1]
                 n += "_%s" % (weight)
             names.append(v.save(n, mpl_kwargs))
         return names
