@@ -23,6 +23,8 @@ def export_rgba(image, fn, h5=True, fits=False, ):
     and saves to *fn*.  If *h5* is True, then it will save in hdf5 format.  If
     *fits* is True, it will save in fits format.
     """
+    if (not h5 and not fits) or (h5 and fits):
+        raise ValueError("Choose either HDF5 or FITS format!")
     if h5:
         f = h5py.File('%s.h5'%fn, "w")
         f.create_dataset("R", data=image[:,:,0])
@@ -31,17 +33,17 @@ def export_rgba(image, fn, h5=True, fits=False, ):
         f.create_dataset("A", data=image[:,:,3])
         f.close()
     if fits:
-        try:
-            import pyfits
-        except ImportError:
-            mylog.error('You do not have pyfits, install before attempting to use fits exporter')
-            raise
-        hdur = pyfits.PrimaryHDU(image[:,:,0])
-        hdug = pyfits.ImageHDU(image[:,:,1])
-        hdub = pyfits.ImageHDU(image[:,:,2])
-        hdua = pyfits.ImageHDU(image[:,:,3])
-        hdulist = pyfits.HDUList([hdur,hdug,hdub,hdua])
-        hdulist.writeto('%s.fits'%fn,clobber=True)
+        from yt.utilities.fits_image import FITSImageBuffer
+        data = {}
+        data["r"] = image[:,:,0]
+        data["g"] = image[:,:,1]
+        data["b"] = image[:,:,2]
+        data["a"] = image[:,:,3]
+        nx, ny = data["r"].shape
+        fib = FITSImageBuffer(data, units="pixel",
+                              center=[0.5*(nx+1), 0.5*(ny+1)],
+                              scale=[1.]*2)
+        fib.writeto('%s.fits'%fn,clobber=True)
 
 def import_rgba(name, h5=True):
     """
